spoon.spooncore.StringIOWrap

Package spoon :: Module spooncore :: Class StringIOWrap |
[hide private]
[frames] | no frames]

# Class StringIOWrap

source code

    object --+
             |
            StringIOWrap

Stupid wrapper around StringIO because it isn't a new style class. GRR!

I'm only implementing the methods that actually make sense for StringIOs and that we actually use.

Instance Methods | [hide private]
`` | __init__(self, sio=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
`` | __iter__(self)
`` | next(self)
`` | getvalue(self)
`` | write(self, data)
`` | read(self, cnt)
`` | close(self)
`` | seek(self, pos)
`` | tell(self)
`` | get_len(self)
`` | get_closed(self)
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
`` | len
`` | closed
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, sio=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __iter__(self) | source code
None

### next(self) | source code
None

### getvalue(self) | source code
None

### write(self, data) | source code
None

### read(self, cnt) | source code
None

### close(self) | source code
None

### seek(self, pos) | source code
None

### tell(self) | source code
None

### get_len(self) | source code
None

### get_closed(self) | source code
None

Property Details | [hide private]

    ### len None Get Method: spoon.spooncore.StringIOWrap.get_len(self) Set Method:
        None
    Delete Method:
        None

    ### closed None Get Method: spoon.spooncore.StringIOWrap.get_closed(self) Set Method:
        None
    Delete Method:
        None